import { COMPANY_NAME, COMPANY_ADDRESS, COMPANY_PHONE, COMPANY_EMAIL } from "@/lib/constants";

export default function SimpleFooter() {
  // Links for footer
  const legalLinks = [
    { name: "Terms & Conditions", href: "/legal/terms" },
    { name: "Privacy Policy", href: "/legal/privacy-policy" },
    { name: "Sitemap", href: "/sitemap" },
  ];

  const serviceLinks = [
    { name: "Wills & Probate", href: "/services/wills-probate" },
    { name: "Family Law", href: "/services/family-law" },
    { name: "Business Law", href: "/services/business-law" },
    { name: "Conveyancing", href: "/services/conveyancing" },
  ];

  return (
    <footer className="bg-gray-50 border-t">
      <div className="container mx-auto px-6 py-12">
        <div className="grid grid-cols-1 md:grid-cols-12 gap-8">
          {/* Company Info & Social */}
          <div className="md:col-span-4">
            <div className="mb-4">
              <picture>
                <source srcSet="/images/bjmckenna-logo.webp" type="image/webp" />
                <img
                  src="/images/bjmckenna-logo.jpg"
                  alt={COMPANY_NAME}
                  className="h-10 w-auto mb-2"
                />
              </picture>
            </div>
            <p className="text-gray-600 mb-4">
              {COMPANY_ADDRESS}
            </p>
            <ul className="space-y-2 mb-6">
              <li>
                <a
                  href={`tel:${COMPANY_PHONE}`}
                  className="text-gray-600 hover:text-primary transition-colors no-underline"
                >
                  {COMPANY_PHONE}
                </a>
              </li>
              <li>
                <a
                  href={`mailto:${COMPANY_EMAIL}`}
                  className="text-gray-600 hover:text-primary transition-colors no-underline"
                >
                  {COMPANY_EMAIL}
                </a>
              </li>
            </ul>
          </div>

          {/* Quick Links */}
          <div className="md:col-span-2">
            <h3 className="font-bold text-gray-900 mb-4">Quick Links</h3>
            <ul className="space-y-2">
              <li>
                <a href="/" className="text-gray-600 hover:text-primary transition-colors no-underline">
                  Home
                </a>
              </li>
              <li>
                <a href="/about" className="text-gray-600 hover:text-primary transition-colors no-underline">
                  About Us
                </a>
              </li>
              <li>
                <a href="/services" className="text-gray-600 hover:text-primary transition-colors no-underline">
                  Services
                </a>
              </li>
              <li>
                <a href="/contact" className="text-gray-600 hover:text-primary transition-colors no-underline">
                  Contact
                </a>
              </li>
              <li>
                <a href="/about/team" className="text-gray-600 hover:text-primary transition-colors no-underline">
                  Our Team
                </a>
              </li>
            </ul>
          </div>

          {/* Services */}
          <div className="md:col-span-3">
            <h3 className="font-bold text-gray-900 mb-4">Our Services</h3>
            <ul className="space-y-2">
              {serviceLinks.map((link) => (
                <li key={link.href}>
                  <a
                    href={link.href}
                    className="text-gray-600 hover:text-primary transition-colors no-underline"
                  >
                    {link.name}
                  </a>
                </li>
              ))}
            </ul>
          </div>

          {/* Legal */}
          <div className="md:col-span-3">
            <h3 className="font-bold text-gray-900 mb-4">Legal</h3>
            <ul className="space-y-2">
              {legalLinks.map((link) => (
                <li key={link.href}>
                  <a
                    href={link.href}
                    className="text-gray-600 hover:text-primary transition-colors no-underline"
                  >
                    {link.name}
                  </a>
                </li>
              ))}
            </ul>
          </div>
        </div>

        {/* Footer Bottom */}
        <div className="border-t border-gray-200 mt-12 pt-8">
          <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
            <div className="text-gray-500 text-sm">
              © {new Date().getFullYear()} {COMPANY_NAME}. All rights reserved.
            </div>
            <div className="text-gray-500 text-sm md:text-right">
              Regulated by the Solicitors Regulation Authority
            </div>
          </div>
        </div>
      </div>
    </footer>
  );
}